function [X,d]=genere_base_de_donnees(P,cell_mu,cell_Gamma,type_bruit,Pomegaj,choix_conserver_la_meme_B)
%
% [X,d]=genere_base_de_donnees(P,cell_mu,cell_Gamma,type_bruit,Pomegaj,choix_conserver_la_meme_B);
%
% entrees
%========
% P est est le nombre d'elements de la base pour chacune des classes
% cell_mu est une cellule de qui contient les vecteurs de moyenne
% cell_Gamma est une cellule de qui contient les differentes matrice de covariance
% type_bruit : 'gaussien', 'gaussien_amplitude_inconnue', 'substitutif'
%
% sorties
%========
% X est une matrice de taille NxP qui contient les differents vecteurs de
% la base
% d est un vecteur de taille P 
%

if nargin<=5
    choix_conserver_la_meme_B=0;
end
% nombre de classes
nb_classe=length(cell_Gamma);
%
if nargin<=4
    Pomegaj=ones(1,nb_classe)/nb_classe;
end
%
if nargin<=3
    type_bruit='gaussien';
end
    
if choix_conserver_la_meme_B==1
    rng default  % For reproducibility
end

% Dimension de x
N=length(cell_mu{1});
%
if nargin<=4
    Pomegaj=ones(nb_classe,1)/nb_classe;
end
%
% nombre d'elements de x pour chaque classe
vec_P=ceil(Pomegaj*P);
cumsum_vec_P=cumsum(vec_P);
%
% on initialise eventuellement plus grand
X=nan(N,cumsum_vec_P(end));
d=nan(cumsum_vec_P(end),1);
%
for c=1:nb_classe
    mu=cell_mu{c};
    Gamma=cell_Gamma{c};
    if c==1
        ind=1:cumsum_vec_P(c);
    else
        ind=(cumsum_vec_P(c-1)+1):cumsum_vec_P(c);
    end
    %
    PP=vec_P(c);
    d(ind)=c;
    if contains(type_bruit,'gaussien')||strcmp(type_bruit,'substitutif')
        %
        if strcmp(type_bruit,'gaussien_amplitude_inconnue')
            %b=6*rand(1,PP).*sign(rand(1,PP)-0.5);
            b=10*(rand(1,PP)-0.5);
            mat_mu=mu*b;
        elseif strcmp(type_bruit,'gaussien_signe_inconnue')
            mat_mu=mu*sign(rand(1,PP)-0.5);
        elseif strcmp(type_bruit,'gaussien_amplitude_positive_inconnue')
            mat_mu=mu*6*rand(1,PP);
        else
            mat_mu=mu*ones(1,PP);
        end
        %
        % gaussien ou substitutif
        if isreal(Gamma)
            X(:,ind)=mat_mu+sqrtm(Gamma)*randn(N,PP);
        else
            X(:,ind)=mat_mu+sqrt(0.5)*sqrtm(Gamma)*(randn(N,PP)+1i*randn(N,PP));
        end
    elseif contains(type_bruit,'laplace')
        U=rand(N,PP)-0.5;
        X(:,ind)=mu+Gamma(1,1)*sign(U).*log(1-2*abs(U));
    else
        disp('pas fini')
        disp('pause')
        pause
    end
end
%
if strcmp(type_bruit,'substitutif')
    seuil=0.8;
    X=X>seuil;
end
%
% on en choisit P parmis ceux generes
%
PP=size(X,2);
%[~,ordre]=sort(rand(1,PP));
ordre=randperm(PP);
%
X=X(:,ordre(1:P));
d=d(ordre(1:P));
%
end
